@@ -20,8 +20,7 @@ from subprocess import Popen
 from typing import Any
 
 from urllib3 import PoolManager, Retry
-from urllib3.exceptions import MaxRetryError, NewConnectionError
-from urllib3.exceptions import TimeoutError as TimeoutErrorUrllib3
+from urllib3.exceptions import HTTPError
 from urllib3.util import Timeout
 from Xlib import X, Xatom, display
 from Xlib.error import DisplayConnectionError
@@ -52,7 +51,7 @@ from umu.umu_util import (
 
 NET_TIMEOUT = 5.0
 
-NET_RETRIES = 1
+NET_RETRIES = 3
 
 RuntimeVersion = tuple[str, str, str]
 
@@ -727,7 +726,7 @@ def get_umu_version_from_manifest(
     if not appid:
         return None
 
-    if appid not in appids:
+    if appid not in set(filter(None, appids)):
         return None
 
     return next(member for member in runtimes if appid in member)
@@ -829,16 +828,35 @@ def umu_run(args: Namespace | tuple[str, list[str]]) -> int:
 
         truststore.inject_into_ssl()
 
-    # Default to retrying requests once, while using urllib's defaults
-    retries: Retry = Retry(total=NET_RETRIES, redirect=True)
-    # Default to a strict 5 second timeouts throughout
-    timeout: Timeout = Timeout(connect=NET_TIMEOUT, read=NET_TIMEOUT)
+    # Configure retry and timeout count for HTTP requests.
+    # Note, the interface for urllib3's Retry and Timeout is a bit awkward
+    # in that some parameters accept 3 types, and depending on the value
+    # creates different results. To keep the UX simple, only allow setting
+    # a value that achieves a disable effect or overriding the default value.
+    retries: bool | int
+    if os.environ.get("UMU_HTTP_RETRIES") == "0":  # Disables retries
+        retries = False
+    elif "UMU_HTTP_RETRIES" in os.environ:
+        retries = int(os.environ["UMU_HTTP_RETRIES"])
+    else:
+        retries = NET_RETRIES
 
-    with (
-        ThreadPoolExecutor() as thread_pool,
-        PoolManager(timeout=timeout, retries=retries) as http_pool,
-    ):
+    timeouts: None | float
+    if os.environ.get("UMU_HTTP_TIMEOUT") == "0":  # Disables timeouts
+        timeouts = None
+    elif "UMU_HTTP_TIMEOUT" in os.environ:
+        timeouts = float(os.environ["UMU_HTTP_TIMEOUT"])
+    else:
+        timeouts = NET_TIMEOUT
+
+    thread_pool = ThreadPoolExecutor()
+    http_pool = PoolManager(
+        timeout=Timeout(connect=timeouts, read=timeouts),
+        retries=Retry(total=retries, redirect=True),
+    )
+    with thread_pool, http_pool:
         session_pools: tuple[ThreadPoolExecutor, PoolManager] = (thread_pool, http_pool)
+
         # Setup the launcher and runtime files
         future: Future = thread_pool.submit(
             setup_umu, UMU_LOCAL / version[1], version, session_pools
@@ -867,14 +885,16 @@ def umu_run(args: Namespace | tuple[str, list[str]]) -> int:
 
         try:
             future.result()
-        except (MaxRetryError, NewConnectionError, TimeoutErrorUrllib3, ValueError):
+        except HTTPError as e:
             if not has_umu_setup():
                 err: str = (
                     "umu has not been setup for the user\n"
                     "An internet connection is required to setup umu"
                 )
                 raise RuntimeError(err)
-            log.debug("Network is unreachable")
+            log.debug(e)
+        except Exception as e:
+            log.exception(e)
 
     # Exit if the winetricks verb is already installed to avoid reapplying it
     if env["EXE"].endswith("winetricks") and is_installed_verb(
