@@ -1,22 +1,22 @@
 import os
 from collections.abc import Callable
-from concurrent.futures import Future, ThreadPoolExecutor
+from concurrent.futures import ThreadPoolExecutor
 from hashlib import sha256
 from http import HTTPStatus
 from pathlib import Path
 from secrets import token_urlsafe
-from shutil import move, rmtree
+from shutil import move
 from subprocess import run
 from tempfile import TemporaryDirectory, mkdtemp
 
 from urllib3.exceptions import HTTPError
-from urllib3.exceptions import TimeoutError as TimeoutErrorUrllib3
 from urllib3.poolmanager import PoolManager
 from urllib3.response import BaseHTTPResponse
 
 from umu.umu_consts import UMU_CACHE, FileLock, HTTPMethod
 from umu.umu_log import log
 from umu.umu_util import (
+    exchange,
     extract_tarfile,
     file_digest,
     get_tempdir,
@@ -41,7 +41,6 @@ def create_shim(file_path: Path):
         file_path (Path, optional): The path where the shim script will be created.
 
     """
-    # Define the content of the shell script
     script_content = (
         "#!/bin/sh\n"
         "\n"
@@ -58,12 +57,7 @@ def create_shim(file_path: Path):
         "# Execute the passed command\n"
         'exec "$@"\n'
     )
-
-    # Write the script content to the specified file path
-    with file_path.open("w") as file:
-        file.write(script_content)
-
-    # Make the script executable
+    file_path.write_text(script_content, encoding="utf-8")
     file_path.chmod(0o700)
 
 
@@ -78,15 +72,16 @@ def _install_umu(
     ret: int = 0  # Exit code from zenity
     thread_pool, http_pool = session_pools
     codename, variant, _ = runtime_ver
-    # Archive containing the runtime
-    archive: str = f"SteamLinuxRuntime_{codename}.tar.xz"
-    base_url: str = (
-        f"https://repo.steampowered.com/steamrt-images-{codename}"
-        "/snapshots/latest-container-runtime-public-beta"
-    )
+    base_url: str = f"https://repo.steampowered.com/{variant}/images/latest-public-beta"
     token: str = f"?versions={token_urlsafe(16)}"
     host: str = "repo.steampowered.com"
-    parts: Path = tmp.joinpath(f"{archive}.parts")
+
+    if codename.removeprefix("steamrt").isdigit():
+        archive = f"SteamLinuxRuntime_{codename.removeprefix('steamrt')}.tar.xz"
+    else:
+        archive = f"SteamLinuxRuntime_{codename}.tar.xz"
+    parts = tmp.joinpath(f"{archive}.parts")
+
     log.debug("Using endpoint '%s' for requests", base_url)
 
     # Download the runtime and optionally create a popup with zenity
@@ -95,13 +90,13 @@ def _install_umu(
         opts: list[str] = [
             "-LJ",
             "--silent",
-            "-O",
             f"{base_url}/{archive}",
-            "--output-dir",
-            str(tmp),
+            "-o",
+            str(parts),
         ]
         msg: str = "Downloading umu runtime, please wait..."
         ret = run_zenity(curl, opts, msg)
+        parts = parts.rename(parts.parent / parts.name.removesuffix(".parts"))
 
     # Handle the exit code from zenity
     if ret:
@@ -111,9 +106,7 @@ def _install_umu(
     if not os.environ.get("UMU_ZENITY") or ret:
         digest: str = ""
         buildid: str = ""
-        endpoint: str = (
-            f"/steamrt-images-{codename}/snapshots/latest-container-runtime-public-beta"
-        )
+        endpoint: str = f"/{variant}/images/latest-public-beta"
         hashsum = sha256()
         headers: dict[str, str] | None = None
         cached_parts: Path
@@ -186,7 +179,7 @@ def _install_umu(
             try:
                 log.debug("Writing: %s", parts)
                 hashsum = write_file_chunks(parts, resp, hashsum)
-            except TimeoutErrorUrllib3:
+            except HTTPError:
                 log.error("Aborting steamrt install due to network error")
                 log.info("Moving '%s' to cache for future resumption", parts.name)
                 move(parts, UMU_CACHE)
@@ -215,54 +208,25 @@ def _install_umu(
             parts.parent / parts.name.removesuffix(f".{buildid}.parts")
         )
 
-    # Open the tar file and move the files
-    log.debug("Opening: %s", parts)
+    local.mkdir(parents=True, exist_ok=True)
+    with TemporaryDirectory(dir=local.parent, prefix=".") as tempdir:
+        log.debug("Created: %s", tempdir)
+        log.debug("Moving: %s -> %s", parts, tempdir)
+        move(parts, tempdir)
 
-    with TemporaryDirectory(dir=UMU_CACHE) as tmpcache:
-        futures: list[Future] = []
-        var: Path = local.joinpath("var")
-        log.debug("Created: %s", tmpcache)
-        log.debug("Moving: %s -> %s", parts, tmpcache)
-        move(parts, tmpcache)
+        extract_tarfile(Path(tempdir, archive), Path(tempdir))
 
-        # Ensure the target directory exists
-        local.mkdir(parents=True, exist_ok=True)
-        log.debug("Extracting: %s -> %s", f"{tmpcache}/{archive}", tmpcache)
-        extract_tarfile(Path(tmpcache, archive), Path(tmpcache))
+        steamrt, *_ = archive.split(".tar.xz")
+        log.debug("Exchanging: %s <-> %s", Path(tempdir, steamrt), local)
+        exchange(Path(tempdir, steamrt), local)
 
-        # Move the files to the correct location
-        source_dir: Path = Path(tmpcache, f"SteamLinuxRuntime_{codename}")
-        var: Path = local.joinpath("var")
-        log.debug("Source: %s", source_dir)
-        log.debug("Destination: %s", local)
-
-        # Move each file to the dest dir, overwriting if exists
-        futures.extend(
-            [
-                thread_pool.submit(_move, file, source_dir, local)
-                for file in source_dir.glob("*")
-            ]
-        )
-
-        if var.is_dir():
-            log.debug("Removing: %s", var)
-            # Remove the variable directory to avoid Steam Linux Runtime
-            # related errors when creating it. Supposedly, it only happens
-            # when going from umu-launcher 0.1-RC4 -> 1.1.1+
-            # See https://github.com/Open-Wine-Components/umu-launcher/issues/213#issue-2576708738
-            thread_pool.submit(rmtree, str(var))
-
-        for future in futures:
-            future.result()
-
-    # Rename _v2-entry-point
-    log.debug("Renaming: _v2-entry-point -> umu")
-    local.joinpath("_v2-entry-point").rename(local.joinpath("umu"))
-
-    create_shim(local / "umu-shim")
-
-    # Validate the runtime after moving the files
-    check_runtime(local, runtime_ver)
+        # Validate and post-install
+        try:
+            check_runtime(local, runtime_ver)
+        finally:
+            log.debug("Linking: umu -> _v2-entry-point")
+            local.joinpath("umu").symlink_to("_v2-entry-point")
+            create_shim(local.joinpath("umu-shim"))
 
 
 def setup_umu(
@@ -302,13 +266,10 @@ def _update_umu(
     The runtime platform will be updated to the latest public beta by
     confirming if the latest platform ID exists in the local VERSIONS.txt
     """
-    runtime: Path
     resp: BaseHTTPResponse
     _, http_pool = session_pools
     codename, variant, _ = runtime_ver
-    endpoint: str = (
-        f"/steamrt-images-{codename}/snapshots/latest-container-runtime-public-beta"
-    )
+    endpoint: str = f"/{variant}/images/latest-public-beta"
     # Create a token and append it to the URL to avoid the Cloudflare cache
     # Avoids infinite updates to the runtime each launch
     # See https://github.com/Open-Wine-Components/umu-launcher/issues/188
@@ -321,7 +282,7 @@ def _update_umu(
     # Find the runtime directory (e.g., sniper_platform_0.20240530.90143)
     # Assume the directory begins with the variant
     try:
-        runtime = max(file for file in local.glob(f"{codename}*") if file.is_dir())
+        max(file for file in local.glob(f"{codename}*") if file.is_dir())
     except ValueError:
         log.critical("*_platform_* directory missing in '%s'", local)
         log.info("Restoring Runtime Platform...")
@@ -367,7 +328,7 @@ def _update_umu(
         return
 
     # Update our runtime
-    _update_umu_platform(local, runtime, runtime_ver, session_pools, resp)
+    _update_umu_platform(local, runtime_ver, session_pools, resp)
 
     # Restore shim if missing
     if not local.joinpath("umu-shim").is_file():
@@ -376,25 +337,6 @@ def _update_umu(
     log.info("%s is up to date", variant)
 
 
-def _move(file: Path, src: Path, dst: Path) -> None:
-    """Move a file or directory to a destination.
-
-    In order for the source and destination directory to be identical, when
-    moving a directory, the contents of that same directory at the destination
-    will be removed.
-    """
-    src_file: Path = src.joinpath(file.name)
-    dest_file: Path = dst.joinpath(file.name)
-
-    if dest_file.is_dir():
-        log.debug("Removing directory: %s", dest_file)
-        rmtree(str(dest_file))
-
-    if src.is_file() or src.is_dir():
-        log.debug("Moving: %s -> %s", src_file, dest_file)
-        move(src_file, dest_file)
-
-
 def check_runtime(src: Path, runtime_ver: RuntimeVersion) -> int:
     """Validate the file hierarchy of the runtime platform.
 
@@ -459,7 +401,6 @@ def _restore_umu(
 
 def _update_umu_platform(
     local: Path,
-    runtime: Path,
     runtime_ver: RuntimeVersion,
     session_pools: SessionPools,
     resp: BaseHTTPResponse,
@@ -482,6 +423,4 @@ def _update_umu_platform(
             return
         log.info("Updating %s to latest...", variant)
         _install_umu(runtime_ver, session_pools, local)
-        log.debug("Removing: %s", runtime)
-        rmtree(str(runtime))
         log.debug("Released file lock '%s'", lock)
